# -*- coding: utf-8 -*-
#
# Copyright (c) 2018, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from oser._if_ import If as _If


class If(_If):
    """
    ``If`` builds a conditional serializer for boolean conditions that is
    invisible if the condition is ``False``.

    It is an alias for
    ``IfElse(condition=condition, if_true=if_true, if_false=Nothing())``
    """

    def __init__(self, condition, if_true):
        """
        Args:
            condition: the condition which selects the desired values. Can be a callable (e.g. lambda) or a scalar.
            if_true: is used if `condition` is `True`.
        """
        super(If, self).__init__(condition=condition, if_true=if_true)

    def byte_size(self):
        """
        Return the current size in bytes.
        """
        return super(If, self).byte_size()

    def decode(self, data, full_data=b'', context_data=b''):
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data (bytes): the data buffer that is decoded.
            full_data (bytes): the binary data string until the part to be decoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context. The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(If, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data=b'', context_data=b''):
        """
        Return the encoded binary string.

        Args:
            full_data (bytes): the binary data string until the part to be
                encoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            bytes: the encoded binary string.
        """
        return super(If, self).encode(full_data=full_data, context_data=context_data)

    def fuzzing_iterator(self, copy=False):
        """
        The fuzzing iterator iterates over all combinations
        of set fuzzing values (:func:`oser.ByteType.set_fuzzing_values`).
        If no fuzzing values are set the current struct is yielded.

        Args:
            copy=False (bool): if set to ``True`` the generated
                fuzzing values are deep copies of the original.
                Creating these deep copies is slow. If set to ``False`` the 
                original struct is retruned and the generated value must be
                used immediately since the next generated overwrites the values
                on the same value.

        Yields:
            the fuzzing combinations.
        """
        return super(If, self).fuzzing_iterator(copy=copy)

    def get(self):
        """
        Return the current value.
        """
        return super(If, self).get()

    def get_current(self):
        """
        Return the currently selected object.
        """
        return super(If, self).get_current()

    def get_false_value(self):
        """
        Return the value for a ``False`` ``condition``.
        """
        return super(If, self).get_false_value()

    def get_true_value(self):
        """
        Return the value for a ``True`` ``condition``.
        """
        return super(If, self).get_true_value()

    def introspect(self, stop_at=None):
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None (object): stop introspection at ``stop_at``.
        """
        return super(If, self).introspect(stop_at=stop_at)

    def root(self):
        """
        return root element
        """
        return super(If, self).root()

    def set(self, value):
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(If, self).set(value=value)

    def set_false_value(self, value):
        """
        Set the value for a ``False`` ``condition``.

        Args:
            value: the new value for a ``False`` ``condition``.
        """
        return super(If, self).set_false_value(value=value)

    def set_true_value(self, value):
        """
        Set the value for a ``True`` ``condition``.

        Args:
            value: the new value for a ``True`` ``condition``.
        """
        return super(If, self).set_true_value(value=value)

    def size(self):
        """
        Return the current size in bytes or bits according to the context.
        """
        return super(If, self).size()

    def up(self):
        """
        return parent element
        """
        return super(If, self).up()

